This library allow the simulation of one- and two-dimension of the scattering
intensities and form factors of prisms with a regular polygon as a cross section.
It can also be used with the ipywidgets package to manually fit experimental
data with the provided models.

Acknowledgements

Created: September 5th, 2024

Creator: Marianne Impéror and Jules Marcone

Original Contributors: Marianne Impéror and Jules Marcone

Examples:
For some examples, please see:


References:
- Theory behind code:
    Wuttke "Numerically stable form factor of any polygon and polyhedron." Journal of Applied Crystallography 54.2 (2021): 580-587

Link:
    https://doi.org/10.1107/S1600576721001710

- Alternate reading:
    Rajouter l'article quand il sera publié
